[![](https://img.shields.io/badge/version-0.3.4-blue)]()
[![pipeline status](https://gitlab.hzdr.de/fwcc/data-management/dms-guidance-system/badges/master/pipeline.svg)](https://gitlab.hzdr.de/fwcc/data-management/dms-guidance-system/-/commits/master)
[![coverage report](https://gitlab.hzdr.de/fwcc/data-management/dms-guidance-system/badges/master/coverage.svg)](https://gitlab.hzdr.de/fwcc/data-management/dms-guidance-system/-/commits/master)
[![](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://www.tidyverse.org/lifecycle/) 
[![](https://img.shields.io/pypi/pyversions/Django)]()
[![](https://img.shields.io/pypi/djversions/djangorestframework)]()

# ![HELIPORT HELmholtz ScIentific Project WORkflow PlaTform](img/logo/heliport_wide.svg) (HZDR Datamanagement Guidance System)

The prototype is located [here](https://vlsdms.fz-rossendorf.de) and can accessed only within the HZDR network (VPN).

The web front-end is developed  in [django](https://www.djangoproject.com) and uses the
buildin security and authentication features and the Admin Dashboard.

Some features:
- Project livecycle support with phases: 
  - Project
  - Systems 
  - Resources 
  - Automation 
  - Results
- Modular integration of systems (see System Architecture)
- Computational workflow management
- Rest api for all important resources
- Collect and export project metadata
- User management


## Setup Local HELIPORT (tested on fresh minimal installation of Ubuntu 20.04.2)

Install requirements for using venv and python-ldap:

```bash
sudo apt-get install python3-venv
sudo apt-get install gcc libsasl2-dev python3-dev libldap2-dev libssl-dev
```
---

Create the python environment with the required packages:

```bash
python3 -m venv venv
source venv/bin/activate
pip install wheel
pip install -r requirements.txt
```
---

Run the server:

**NOTE:** `makemigrations` and `migrate` is only required if the database schema changed since last start

**NOTE:** Listing all apps for `makemigrations` is not required in some environments (if no migrations are made you need to)

**NOTE:** A full list of apps can be found in `heliport_system/heliport_project/settings.py` -> `_HELIPORT_SYSTEM_APPS`

```bash
cd heliport_system/
export LOCAL_EXECUTION=True
export SECRET_KEY=some_random_string_as_secret_key
python manage.py makemigrations <app_name_1> <app_name_2> ... <app_name_n>
python manage.py migrate
python manage.py runserver
```
---

Change authentication in `settings.py` or setup a ldap server on port `10389`.
One option is to use port forwarding similar to the following command:
```bash
ssh -L 10389:ldap.fz-rossendorf.de:389 <user>@uts.hzdr.de
```

### Additional Tips

If you want an admin for the `/admin/` interface, you can create one:
```bash
python manage.py createsuperuser
```
---

If you don't want to type `LOCAL_EXECUTION=True` and `SECRET_KEY=...` every time,
create a file `heliport_system/heliport_project/.env` with the following content:
```
SECRET_KEY=...
LOCAL_EXECUTION=True
```
Additionally, you should add `CRYPTO_KEY=...` to your `.env` file to encrypt ssh keys 
and set `GATE_TOKEN_STR=ClientId:ClientSecret` to a token generated by your local GATE administrator

**NOTE:** If you don't set `CRYPTO_KEY` you get an error including a generated key example when you try to establish an ssh connection

**NOTE:** If you don't set `GATE_TOKEN_STR` you get an error when you try to sync GATE projects, to disable the GATE app entirely 
remove it from `settings.py` and `included_urls.py` (see "How To Integrate a new Module" below)

---

If you have problems with PyCharm suggesting incorrect python modules:
- Right click on the `heliport_system` folder
- Goto "Mark Directory as"
- Select "Sources root"
- The `heliport_system` folder should be displayed in blue


## How to Integrate a new Module
Start your django app with:
```bash
python manage.py startapp your_app_name
```
---

After you changed the database schema update the database:

**NOTE:** In some environments `your_app_name` might not be required as by default migrations for all apps are made

**NOTE:** Don't forget to add makemigrations command to ci job if you have one

```bash
python manage.py makemigrations your_app_name
python manage.py migrate
```
---

Update the following settings in `settings.py`:
- Add `your_app_name` to the `_HELIPORT_SYSTEM_APPS` list
- Add your modules to a phase in `GRAPH`
  - Refer to a module by its "module_id" (see "Export an Interface" below)
- If your modules have any dependencies, add them to `DEPENDENCIES`
  - Refer to a module by its "module_id"

---
Add `path('your_app_name/', include('your_app_name.urls'))`, to `heliport_system/included_urls.py`.

### Export an Interface to HELIPORT
Create a file called "`interface.py`" in the folder of your app
- `from heliport.graph_generator import Module`
- Create one or more classes that inherit from `Module` with the following fields:
  - Property `name`: The name shown in project graph 
  - Property `module_id`: The name used in `settings.py` to refer to this module 
  - Function `get_url(project)`: The link to your initial view of the app for a project 
  - Function `is_configured(project)`: Return `True` if module should be shown in project graph (e.g. check if the user created at least one object in your module for that project)
- If your app has an API add a function `get_api_root()` with no arguments returning the url to a simple describing page of your api
- To make objects in your app searchable with the global search add a function `get_search_url()` with no arguments returning the url to a view that renders a html div containing search results given a query parameter `q=multi word search string`
- To make objects of your app appear in the metadata schema of a project add a function `serialize_project(project)` returning a `dict` that gets merged with the metadata returned by other apps
- Add `from . import interface` to `__init__.py` of your app


### Use HELIPORT infrastructure inside your app
- Use the heliport `base.html` in your templates:
  - Begin your template with `{% extends 'core/base.html' %}` 
  - Implement 
    ```html
    {% block content %} 
    <!-- your content --> 
    {% endblock %}
    ```
  - If you have scripts use
    ```html
    {% block script %} 
    <script>
        // your scripts 
    </script>
    {% endblock %}
    ```
- To extend the HELIPORT project model in `models.py`
  - `from heliport.models import Project` 
  - Create `project = models.ForeignKey(Project, on_delete=models.CASCADE)` field in your model
- To use HELIPORT views
  - `from heliport.custom_views import HeliportObjectView, HeliportProjectView` 
  - If you want a view for an HELIPORT project use `HeliportProjectView`, make sure your url parameter is called "project" 
  - If you want a view for a model with `ForeignKey` called "project" use `HeliportObjectView` 
  - If you make `HeliportObectView` or `HeliportProjectView` the first parent of your view class, 
    authorization of the user to access the project is ensured
  - Both views include "project" in the context for rendering  

## System Architecture
### System Overview
![architecture](img/Heliport_Architecture.png)

### Database Model

The database can be found at `vlspgdb0:dms` in our 
[PostgreSQL Infrastructure](https://gitlab.hzdr.de/fwcc/data-management/postgres-server-infrastructure). 
For modeling the [django-schema-graph](https://github.com/meshy/django-schema-graph) can be used.

![database-schema](img/database.png)


## Metadata Schema
* Based on [DataCite 4.3](http://schema.datacite.org/meta/kernel-4.3/) and can be visualized using `xsdvi`
* Additional basic vocabularies like 
  [RDF schema](https://www.w3.org/TR/rdf-schema/), 
  [OWL time](https://www.w3.org/TR/owl-time/)

### Handle System
* Our HZDR-ID concept for heliport projects: **HZDR.FWCC.2021.95018**
* Handle for project: [https://hdl.handle.net/20.500.12865/HZDR.FWCC.2021.95018](https://hdl.handle.net/20.500.12865/HZDR.FWCC.2021.95018)
