from django.test import TestCase
from django.contrib.auth.models import User
from django.shortcuts import reverse

from heliport.models import Project, HeliportUser
from .models import Archive


class ArchiveTests(TestCase):
    def setUp(self):
        self.auth_user, is_new = User.objects.get_or_create(username='testuser')
        self.user, is_new = HeliportUser.objects.get_or_create(auth_user=self.auth_user)
        self.client.force_login(self.auth_user)
        self.project = Project.objects.create(owner=self.user)

    def test_list(self):
        a = Archive.objects.create(project=self.project)
        response = self.client.get(reverse('archive:list', kwargs={'project': self.project.pk}))
        self.assertEquals(200, response.status_code)
        self.assertEquals(a, response.context_data['project'].archive_set.filter(pk=a.pk).first())

    def test_create(self):
        self.client.post(reverse('archive:list', kwargs={'project': self.project.pk}),
                         data={'description': 'test_archive321'})
        self.assertIsNotNone(self.project.archive_set.filter(description='test_archive321').first())


class SearchTest(TestCase):
    def setUp(self):
        self.auth_user, is_new = User.objects.get_or_create(username='testuser')
        self.user, is_new = HeliportUser.objects.get_or_create(auth_user=self.auth_user)
        self.project, is_new = Project.objects.get_or_create(owner=self.user)
        self.client.force_login(self.auth_user)

    def test_access_search(self):
        response = self.client.get(reverse('archive:search'))
        self.assertEquals(200, response.status_code)

    def test_archive_findable(self):
        Archive.objects.create(project=self.project, description='ARCHIVE321')
        response = self.client.get(f'{reverse("archive:search")}?q=321')
        self.assertContains(response, 'ARCHIVE321')
