from django.db.models import Q
from django.shortcuts import get_object_or_404, reverse

from heliport.custom_views import HeliportProjectView, HeliportLoginRequiredMixin, django_views
from .models import *


class ArchiveView(HeliportProjectView, django_views.CreateView):
    model = Archive
    template_name = 'archive/archive.html'
    fields = ['description']

    def form_valid(self, form):
        project = get_object_or_404(Project, pk=self.kwargs['project'])
        form.instance.project = project
        return super().form_valid(form)

    def get_success_url(self):
        return reverse('archive:list', kwargs=self.kwargs)


class SearchView(HeliportLoginRequiredMixin, django_views.TemplateView):
    template_name = "archive/search.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        user = self.request.user.heliportuser
        query = self.request.GET.get('q', '')
        context["query"] = query

        archive_results = set()

        for word in query.split():
            num = int(word) if word.isnumeric() else -1

            archive_results.update(Archive.objects.filter(
                (Q(project__owner=user) | Q(project__co_owner=user)) &
                (
                    Q(archive_id=num) |
                    Q(description__icontains=word)
                )
            ))

        context["archive_results"] = archive_results
        return context
