from django.urls import path, include
from rest_framework import routers

from .views import *

app_name = 'cwl_execution'
urlpatterns = [
    path('project/<int:project>/arbitrary_cwl/list/', ArbitraryCWLListView.as_view(), name='arbitrary_cwl_list'),
    path('project/<int:project>/arbitrary_cwl/update/<int:pk>/', ArbitraryCWLUpdateView.as_view(), name='arbitrary_cwl_update'),
    path('project/<int:project>/job/create_from/<int:executable>/', JobCreateView.as_view(), name='job_create'),
    path('project/<int:project>/executable/<int:executable>/job/<int:pk>/update/', JobCreateView.as_view(), name='job_update'),
    path('project/<int:project>/job/list/', JobListView.as_view(), name='job_list'),
    path('project/<int:project>/job/running/', RunningJobsView.as_view(), name='job_running'),
    path('project/<int:project>/job/<int:pk>/start/', JobStartView.as_view(), name='job_start'),
    path('project/<int:project>/job/<int:pk>/CWL/YAML/', JobRawYamlView.as_view(), name='job_cwl_yaml'),
    path('project/<int:project>/job/<int:pk>/detail/', JobDetailView.as_view(), name='job_detail'),
    path('project/<int:project>/job/<int:pk>/output/', JobOutputView.as_view(), name='job_output'),
    path('project/<int:project>/job/<int:pk>/debug/', JobDebugView.as_view(), name='job_debug'),
    path('project/<int:project>/job/<int:pk>/stop/', JobStopView.as_view(), name='job_stop'),
    path('project/<int:project>/tool/list/', ToolListView.as_view(), name='tool_list'),
    path('project/<int:project>/tool/<int:pk>/CWL/YAML/', ExecutableRawYamlView.as_view(), name='exe_cwl_yaml'),
    path('project/<int:project>/tool/<int:pk>/description/', ToolJsonDescriptionView.as_view(), name='tool_description'),
    path('project/<int:project>/tool/<int:pk>/update/', ToolUpdateView.as_view(), name='tool_update'),
    path('project/<int:project>/tool/create/', ToolCreateView.as_view(), name='tool_create'),
    path('project/<int:project>/workflow/list/', WorkflowListView.as_view(), name='workflow_list'),
    path('project/<int:project>/workflow/<int:pk>/update/', WorkflowUpdateView.as_view(), name='workflow_update'),
    path('project/<int:project>/workflow/create/', WorkflowCreateView.as_view(), name='workflow_create'),
    path('manually/start/periodic/jobs/', ManualPeriodicJobsView.as_view(), name='manual_periodic_job_start'),
    path('project/<int:project>/executable/<int:pk>/visualization_data/', VisualizationDataView.as_view(), name='visualization_data'),
    path('search/', SearchView.as_view(), name='search'),
]

# for REST API:
router = routers.DefaultRouter()
router.register(r'executable', ExecutableViewSet, basename='executable')
router.register(r'job', JobViewSet, basename='job')
router.register(r'user_job_config', UserJobConfigViewSet, basename='user_job_config')

urlpatterns += [
    path('api-root/', router.get_api_root_view(), name='api_root'),
    path('api/', include(router.urls)),
]
