from django.urls import reverse

from heliport.graph_generator import Module


class DataSourceModule(Module):
    name = 'Data Source'
    module_id = 'data_source'

    def get_url(self, project):
        return reverse('data_source:list', kwargs={'project': project.pk})

    def is_configured(self, project):
        return project.datasource_set.all()


def get_api_root():
    return reverse('data_source:api_root')


def get_search_url():
    return reverse('data_source:search')


def serialize_project(project):
    query = project.datasource_set.all()
    result = dict()
    if query:
        result['heliport:has_DataSource'] = [
            {
                'heliport:data_source_id': ds.data_source_id,
                'datacite:uri': ds.uri,
                'heliport:use_computer': ds.login.machine if ds.login else None,
                'rdfs:label': ds.name,
                'datacite:hasDescription': ds.description,
            }
            for ds in query
        ]

    return result
