from django.urls import reverse

from heliport.graph_generator import Module


class DocumentationModule(Module):
    name = 'Documentation'
    module_id = 'documentation'

    def get_url(self, project):
        return reverse('documentation:list', kwargs={'project': project.pk})

    def is_configured(self, project):
        return project.documentation_set.all()


def get_api_root():
    return reverse('documentation:api_root')


def get_search_url():
    return reverse('documentation:search')


def serialize_project(project):
    query = project.documentation_set.all()
    result = dict()
    if query:
        result['heliport:has_Documentation'] = [
            {
                'heliport:documentation_id': doc.documentation_id,
                'datacite:uri': doc.link,
                'heliport:documentation_system': {key: value for key, value in doc.DOCU_SYSTEMS}.get(doc.system),
                'datacite:hasDescription': doc.description,
            }
            for doc in query
        ]

    return result
