from django.urls import reverse

from heliport.graph_generator import Module


class GATEConnectionModule(Module):
    name = 'GATE Connection'
    module_id = 'gate_connection'

    def get_url(self, project):
        gate_project = project.gateproject_set.first()
        if gate_project is None:
            return reverse('gate_connection:connect', kwargs={'project': project.pk})

        return reverse('gate_connection:connected', kwargs={'project': project.pk, 'pk': gate_project.pk})

    def is_configured(self, project):
        return project.gateproject_set.all()


def get_api_root():
    return reverse('gate_connection:api_root')


def get_search_url():
    return reverse('gate_connection:search')


def serialize_project(project):
    query = project.gateproject_set.all()
    if not query:
        return dict()

    def user_dict(user):
        return {
            'datacite:hasIdentifier': user.authentication_backend_id,
            'datacite:orcid': user.orcid,
            'rdfs:label': user.display_name
        }

    gate_projects = []
    for gate_project in query:
        result = {
            'heliport:gate_id': gate_project.gate_id,
            'dc:title': gate_project.title,
            'heliport:status': gate_project.status,
            'dc:abstract': gate_project.abstract,
            'datacite:hasIdentifier': gate_project.proposal,
            'dc:accessRights': not gate_project.restricted,
        }

        if gate_project.proposer:
            result['dc:creator'] = user_dict(gate_project.proposer)
        if gate_project.responsible_experimentalist:
            result['heliport:responsible_experimentalist'] = user_dict(gate_project.responsible_experimentalist)

        co_proposer = [user_dict(guy) for guy in gate_project.co_proposer.all()]
        if co_proposer:
            result['dc:contributor'] = co_proposer

        local_contacts = [user_dict(guy) for guy in gate_project.local_contacts.all()]
        if local_contacts:
            result['heliport:local_contacts'] = local_contacts

        gate_projects.append(result)

    return {'heliport:has_GATEProject': gate_projects}
