from .user_management import User, UserQueries


class GateUser(User):
    @staticmethod
    def create_user(user_id, gate_manager):
        return gate_manager.create_gate_user(user_id)

    @staticmethod
    def extract_users(project):
        return [
            project.proposer,
            project.responsible_experimentalist,
            *project.co_proposers
        ]

    def __init__(self, gate_id, gate_manager):
        self.gate_manager = gate_manager
        self.gate_id = gate_id
        self.url = "https://www.hzdr.de/db/proposalmanagement/user/details"
        self.ldap_cn = None
        self.name = None

    def __hash__(self):
        return hash(self.gate_id)

    def __eq__(self, other):
        if isinstance(other, GateUser):
            return self.gate_id == other.gate_id
        else:
            return False

    def download(self, connection):
        # example data
        # {
        #    'id': 2000123,
        #    'geco': 'Dipl.-Ing. Dr. John Doe',
        #    'affiliation': 'Helmholtz-Zentrum Dresden-Rossendorf',
        #    'userdb': 101234,
        #    'userdb_name': 'Doe, Dr. John (OncoRay) - 101234',
        #    'links': [{'rel': 'collection', 'href': 'https://www.hzdr.de/db/proposalmanagement/user/'}]
        # }
        command = f'curl -i -k -H "Authorization: Bearer {self.gate_manager.token}" {self.url}?uid={self.gate_id}'
        data = connection.execute(command).extract_http_json()

        alt_name = f"{data['geco']} (extern)"
        self.ldap_cn = data["userdb"]
        self.name = data["userdb_name"] or alt_name

    def get_db_user_from(self, user_queries: UserQueries):
        user = None

        if self.ldap_cn is not None:
            # if user has logged in before having gate project
            # protect if gate id is duplicated (happens in very rare cases)
            user = user_queries.get_user_by_ldap_id_check_gate_duplication(ldap_id=self.ldap_cn, gate_id=self.gate_id)

        if user is None:
            user = user_queries.get_user_by_gate_id(self.gate_id)

        if user is None:
            user = user_queries.create_user()

        return user

    def save_to(self, user_queries: UserQueries):
        user = self.get_db_user_from(user_queries)
        user_queries.update_user(
            user,
            display_name=self.name,
            ldap_id=self.ldap_cn,
            gate_id=self.gate_id
        )

    def check_new(self, user_queries: UserQueries):
        return user_queries.get_user_by_gate_id(self.gate_id) is None
