from .user_management import User
from .user_management import UserQueries


class LDAPUser(User):
    @staticmethod
    def create_user(user_id, gate_manager):
        return gate_manager.create_ldap_user(user_id)

    @staticmethod
    def remove_prefix_strip(line, prefix):
        line = line.strip()
        if line.startswith(prefix):
            return line[len(prefix):]
        else:
            raise ValueError(f'line starts not with "{prefix}"')

    @classmethod
    def extract_users(cls, project):
        return project.local_contacts

    def __init__(self, ldap_id):
        self.ldap_id = ldap_id
        self.name = None

    def __hash__(self):
        return hash(self.ldap_id)

    def __eq__(self, other):
        if isinstance(other, LDAPUser):
            return self.ldap_id == other.ldap_id
        else:
            return False

    def generate_download_command(self):
        url = "ldap.fz-rossendorf.de"
        ldap_info = "ou=db,ou=it,o=fsr,dc=de"
        download_command = (
            f'ldapsearch -D "" -h {url} -b "{ldap_info}" -s sub "(cn:={self.ldap_id})" | grep "displayName: "'
        )
        return download_command

    def download(self, connection):
        command = self.generate_download_command()
        out = connection.execute(command).stdout

        self.name = self.remove_prefix_strip(out, "displayName: ")

    def get_db_user_from(self, user_queries: UserQueries):
        user = user_queries.get_user_by_ldap_id(self.ldap_id)
        if user is None:
            user = user_queries.create_user()
        return user

    def save_to(self, user_queries: UserQueries):
        user = self.get_db_user_from(user_queries)
        user_queries.update_user(
            user,
            display_name=self.name,
            ldap_id=self.ldap_id
        )

    def check_new(self, user_queries: UserQueries):
        return user_queries.get_user_by_ldap_id(self.ldap_id) is None
