from heliport.logger import logger

from .hzdr_gate_proposal_management import HZDRGateProposalManager


class UpdateProposalDatabaseUseCase:

    def __init__(self, user_queries, gate_queries):
        self.user_queries = user_queries
        self.gate_queries = gate_queries

    def execute(self):
        with HZDRGateProposalManager() as proposal_manager:
            self.update_gate_database(proposal_manager)

    def update_gate_database(self, proposal_manager):
        logger.info("=== GET GATE DATABASE START ===")

        proposal_data = proposal_manager.download_proposals()
        proposal_manager.import_users(proposal_data, self.user_queries)

        logger.info("=== WRITE GATE PROJECTS TO DATABASE ===")
        for i, project in enumerate(proposal_data):
            proposal_manager.save_proposal(project, self.gate_queries)
            if i % 100 == 0:
                logger.debug(f'{i} / {len(proposal_data)} gate projects updated')

        logger.info(f"{len(proposal_data)} gate projects imported")
        logger.info("=== GET GATE DATABASE FINISH ===")
        return len(proposal_data)
