from django.contrib.auth.mixins import LoginRequiredMixin, UserPassesTestMixin
from django.shortcuts import get_object_or_404
import django.views.generic as django_views

from .models import Project


class HeliportLoginRequiredMixin(LoginRequiredMixin):
    login_url = '/login'
    permission_denied_message = 'Please log in to view this site'
    raise_exception = False


class HeliportProjectView(HeliportLoginRequiredMixin, UserPassesTestMixin):
    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context['project'] = get_object_or_404(Project, pk=self.kwargs['project'])
        return context

    def test_func(self):
        user = self.request.user.heliportuser
        project = get_object_or_404(Project, pk=self.kwargs['project'])
        return user in project.members()


class HeliportObjectView(HeliportLoginRequiredMixin, UserPassesTestMixin):
    def test_func(self):
        user = self.request.user.heliportuser
        project = self.get_object().project
        return user in project.members()

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["project"] = self.object.project
        return context
