from django.urls import reverse

from heliport.graph_generator import Module


class ProjectConfigurationModule(Module):
    name = 'Project Configuration'
    module_id = 'project_configuration'

    def get_url(self, project):
        return reverse('heliport:project', kwargs={'project': project.pk})

    def is_configured(self, project):
        return project.project_name


def get_search_url():
    return reverse('heliport:search')


def serialize_project(project):
    def user_dict(user):
        if user is None:
            return None
        return {
            'datacite:hasIdentifier': user.authentication_backend_id,
            'datacite:orcid': user.orcid,
            'rdfs:label': user.display_name
        }

    result = {
        'heliport:project_id': project.project_id,
        'datacite:hasIdentifier': project.hzdr_id,
        'heliport:uuid': project.uuid,
        'datacite:handle': f'https://hdl.handle.net/{project.handle}',
        'heliport:project_name': project.project_name,
        'time:hasBeginning': str(project.created),
        'datacite:hasDescription': project.description,
        'heliport:group': str(project.group),
        'heliport:owner': user_dict(project.owner)
    }

    if project.deleted:
        result['time:hasEnd'] = str(project.deleted)

    co_owner = project.co_owner.all()
    if co_owner:
        result['heliport:co_owner'] = [user_dict(guy) for guy in co_owner]

    return result
