import logging
import abc

from django.conf import settings

logging.basicConfig(filename=settings.LOG_FILENAME,
                    format=settings.LOG_FORMAT,
                    datefmt=settings.LOG_FORMAT_TIME,
                    level=settings.LOG_LEVEL)


class Logger:
    @abc.abstractmethod
    def log(self, message, level):
        pass

    def debug(self, message):
        self.log(message, logging.DEBUG)

    def info(self, message):
        self.log(message, logging.INFO)

    def warning(self, message):
        self.log(message, logging.WARNING)

    def error(self, message):
        self.log(message, logging.ERROR)

    def critical(self, message):
        self.log(message, logging.CRITICAL)


class FileLogger(Logger):
    def log(self, message, level):
        logging.log(level, message)


class ConsoleLogger(Logger):
    def log(self, message, level):
        if level >= settings.LOG_LEVEL:
            print(message)


if settings.LOG_TO_CONSOLE:
    logger = ConsoleLogger()
else:
    logger = FileLogger()

if __name__ == "__main__":
    logger.log("abc", logging.DEBUG)
