from rest_framework import permissions
from django.db.models import Q

from .models import Project


class HeliportProjectPermission(permissions.BasePermission):
    def has_object_permission(self, request, view, obj):
        if not hasattr(request.user, 'heliportuser'):
            return False
        return request.user.heliportuser in obj.members()


class HeliportObjectPermission(permissions.BasePermission):
    def has_object_permission(self, request, view, obj):
        if not hasattr(request.user, 'heliportuser'):
            return False
        return request.user.heliportuser in obj.project.members()


def projects_of(heliport_user):
    return Project.objects.filter(Q(owner=heliport_user) | Q(co_owner=heliport_user))


def is_object_member(heliport_user):
    return Q(project__owner=heliport_user) | Q(project__co_owner=heliport_user)


class StaffOrReadOnly(permissions.BasePermission):
    def has_object_permission(self, request, view, obj):
        return request.user.is_staff or request.method in permissions.SAFE_METHODS
