import json
from django.test import TestCase
from django.contrib.auth.models import User
from django.shortcuts import reverse

from .models import HeliportUser, Project, Group


class DummyTest(TestCase):
    def test_success(self):
        assert 1 == 1, "one equals one"

    def test_dont_fail(self):
        assert 1 + 1 == 2, "two equals two"


class SearchTest(TestCase):
    def setUp(self):
        self.auth_user, is_new = User.objects.get_or_create(username='testuser')
        self.user, is_new = HeliportUser.objects.get_or_create(auth_user=self.auth_user, display_name='HELIPORTUSER321')
        self.client.force_login(self.auth_user)

    def test_access_search(self):
        response = self.client.get(reverse('heliport:search_base'))
        self.assertEquals(200, response.status_code)

    def test_search_valid_redirect_urls(self):
        response = self.client.get(reverse('heliport:search_base'))
        self.assertEquals(200, response.status_code)
        urls = response.context_data['search_urls']
        self.assertIn(reverse('heliport:search'), urls)
        self.assertGreater(len(urls), 1, 'modules other than heliport app are not searchable')

        for url in urls:
            response = self.client.get(url)
            self.assertEquals(200, response.status_code)

    def test_group_findable(self):
        Group.objects.create(group_id='GROUP321')
        response = self.client.get(f'{reverse("heliport:search")}?q=321')
        self.assertEquals(200, response.status_code)
        self.assertContains(response, 'GROUP321')

    def test_heliport_user_and_project_findable(self):
        Project.objects.create(owner=self.user, project_name='PROJECT321')
        response = self.client.get(f'{reverse("heliport:search")}?q=321')
        self.assertEquals(200, response.status_code)
        self.assertContains(response, 'HELIPORTUSER321')
        self.assertContains(response, 'PROJECT321')


class HELIPORTTest(TestCase):
    def setUp(self):
        self.auth_user, is_new = User.objects.get_or_create(username='testuser')
        self.user, is_new = HeliportUser.objects.get_or_create(auth_user=self.auth_user)
        self.project, is_new = Project.objects.get_or_create(owner=self.user, project_name='xabac')
        self.client.force_login(self.auth_user)

    def test_project_graph(self):
        response = self.client.get(reverse('heliport:project_graph', kwargs={'project': self.project.pk}))
        self.assertEquals(200, response.status_code)
        self.assertContains(response, 'xabac')

    def test_simple_api_docu(self):
        """mirroring the way it is described in projects api view"""

        response = self.client.get('/api-root/')
        self.assertEquals(200, response.status_code)
        urls = json.loads(response.content.decode())

        response = self.client.get(urls['projects'])
        self.assertEquals(200, response.status_code)
        response = self.client.get(f'{urls["projects"]}urls/')
        self.assertEquals(200, response.status_code)
        urls = json.loads(response.content.decode())

        self.assertIsInstance(urls, list)
        self.assertGreater(len(urls), 0, 'there are no api urls other than the main heliport app api')
