from django.urls import path, include
from rest_framework import routers
from rest_framework.authtoken import views as rest_auth_views

from .views import *

app_name = 'heliport'
urlpatterns = [
    path('login/', LoginView.as_view(), name='login'),
    path('logout/', LogoutView.as_view(), name='logout'),
    path('user/settings/', UserSettingsView.as_view(), name='user_settings'),
    path('user/logins/list/', LoginInfoView.as_view(), name='user_login_list'),
    path('user/logins/update/<int:pk>/', LoginInfoUpdateView.as_view(), name='user_login_update'),
    path('user/logins/remote_server_login/<int:pk>/', RemoteServerLoginView.as_view(), name='remote_server_login'),
    path('user/logins/remote_server_logout/<int:pk>/', RemoteServerLogoutView.as_view(), name='remote_server_logout'),
    path('project/list/', ProjectListView.as_view(), name='project_list'),
    path('project/create/', CreateProjectView.as_view(), name='project_create'),
    path('project/<int:project>/graph/', ProjectGraphView.as_view(), name='project_graph'),
    path('project/<int:project>/', ProjectView.as_view(), name='project'),
    path('project/update/<int:project>/', ProjectUpdateView.as_view(), name='project_update'),
    path('manually/update/user/database/', ManualUserDownloadView.as_view()),
    path('', IndexView.as_view(), name='index'),
    path('project/<int:project>/autocomplete_user/', get_users_autocomplete),
    path('project/<int:project>/serialize/', ProjectSerializationView.as_view(), name='project_serialize'),
    path('project/dropdown_project_list/', get_project_list),
    path('search_base/', SearchBaseView.as_view(), name='search_base'),
    path('search/', SearchView.as_view(), name='search'),
    path('favicon.ico', FaviconView.as_view())
]

# for REST API:
router = routers.DefaultRouter()
router.register(r'projects', ProjectViewSet, basename='projects')
router.register(r'users', UserViewSet, basename='users')
router.register(r'groups', GroupViewSet, basename='groups')

urlpatterns += [
    path('api-root/', router.get_api_root_view(), name='api_root'),
    path('api/', include(router.urls)),
    path('token/', rest_auth_views.obtain_auth_token, name='get_token'),
    path('openapi/', SchemaVew, name='openapi-schema'),
    path('redoc/', RedocView.as_view(), name='redoc')
]
