import os
from django.conf import settings
from heliport.logger import logger
from heliport.utils import environment
from utils.command_line_execution import create_command_executor


SSH_PUBLIC_KEY_NAME = settings.SSH_KEY_NAME + '.pub'


def download_ssh_key(login_info, username, password):
    logger.debug(f'start ssh key exchange with {login_info.machine}')
    machine = login_info.machine
    indirection = login_info.build_command_executor_indirection()

    executor = create_command_executor(host=machine, username=username, password=password, indirection=indirection)
    with executor:
        logger.debug(f"connected to {login_info.machine}")
        c = f'cd ~/.ssh/ ; ssh-keygen -C "{username}@HELIPORT" -t rsa -f {settings.SSH_KEY_NAME} -q -P ""'
        executor.execute(c, command_input='n')
        executor.execute(f'cd ~/.ssh/ ; cat {SSH_PUBLIC_KEY_NAME} >> authorized_keys')
        logger.debug(f'ssh-keygen returned successfully')

        pwd = executor.execute('pwd').stdout.rstrip('\n\r')
        private_path = os.path.join(pwd, '.ssh', settings.SSH_KEY_NAME)
        public_path = os.path.join(pwd, '.ssh', SSH_PUBLIC_KEY_NAME)
        login_info.data = executor.file(public_path).read().decode()
        private_key = executor.file(private_path).read().decode()
        login_info.key = executor.encrypt(private_key, environment.get_paramiko_krypto_key())
        logger.debug(f'downloaded keys from {login_info.machine}')

    login_info.save()
    logger.info(f'successfully connected to {login_info.machine}')


def delete_ssh_key(login_info):
    executor = login_info.build_command_executor()
    public_key = login_info.data.strip()
    login_info.data = ''
    login_info.key = ''
    login_info.save()

    with executor:
        escaped_public_key = ''.join(fr'\{c}' if c in r'$.*/[\]^' else c for c in public_key)
        executor.execute(f"sed -i '/{escaped_public_key}/d' ~/.ssh/authorized_keys")
        executor.execute(f'rm -i -f ~/.ssh/{settings.SSH_KEY_NAME}')
        executor.execute(f'rm -i -f ~/.ssh/{SSH_PUBLIC_KEY_NAME}')
