import json
import requests
from datetime import datetime
from base64 import b64encode
from django.conf import settings
from heliport.logger import logger


def register_json_handle(handle_name, object_category, url):
    data = {
        'id': handle_name,
        'created_on': datetime.now().strftime('%Y/%m/%d, %H:%M'),
        'instance_of': object_category,
        'description': settings.HANDLE_DESCRIPTION,
        'url': url
    }
    prefix = 'data:application/json;charset=utf-8;base64,'
    data_url = prefix + b64encode(json.dumps(data).encode('utf-8')).decode()
    return register_handle(handle_name, data_url)


def register_handle(handle_name, target_url):
    handle_url = f'{settings.HANDLE_API_URL}/{settings.HANDLE_PREFIX}/{handle_name}?overwrite=false'
    headers = {'Authorization': 'Handle clientCert="true"', 'Content-Type': 'application/json'}
    value = {'format': 'string', 'value': target_url}
    request_data = {'index': 1, 'type': 'URL', 'data': value}
    cert = (settings.HANDLE_CERTIFICATE_PATH, settings.HANDLE_PRIVATE_KEY_PATH)

    answer = requests.put(handle_url, json.dumps(request_data), headers=headers, cert=cert)
    if answer.status_code == 409:
        handle_url = f'{settings.HANDLE_API_URL}/{settings.HANDLE_PREFIX}/?mintNewSuffix=true'
        answer = requests.put(handle_url, json.dumps(request_data), headers=headers, cert=cert)

    logger.info(f'created handle {answer.status_code} {answer.json()}')
    return answer
