from __future__ import absolute_import

import os

from celery import Celery, shared_task
from django.conf import settings

# set the default Django settings module for the 'celery' program.
os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'heliport_project.settings')

app = Celery('heliport_project')

# Load task modules from all registered Django app configs.
app.config_from_object('django.conf:settings')

app.autodiscover_tasks(lambda: settings.INSTALLED_APPS)

task_routes = {
    'heliport_project.celery.add': 'celery',
    'heliport_project.tasks.import_user_data': 'celery',
    'cwl_execution.tasks.job_start': 'celery',
    'cwl_execution.tasks.run_periodic_jobs': 'celery',
    'gate_connection.tasks.update_gate_projects': 'celery',
}

task_annotations = {
    'cwl_execution.tasks.job_start': {'rate_limit': '10/m'}
}


@shared_task
def add(x, y):
    return x + y
