import json
from django.test import TestCase
from django.contrib.auth.models import User
from django.shortcuts import reverse

from heliport.models import Project, HeliportUser
from .models import Publication


class PublicationTests(TestCase):
    def setUp(self):
        self.auth_user, is_new = User.objects.get_or_create(username='testuser')
        self.user, is_new = HeliportUser.objects.get_or_create(auth_user=self.auth_user)
        self.client.force_login(self.auth_user)
        self.project = Project.objects.create(owner=self.user)

    def test_list(self):
        Publication.objects.create(project=self.project)
        response = self.client.get(reverse('publication:list', kwargs={'project': self.project.pk}))
        self.assertEqual(response.status_code, 200)
        self.assertGreater(len(response.context_data['project'].publication_set.all()), 0)

    def test_create(self):
        self.client.post(reverse('publication:list', kwargs={'project': self.project.pk}),
                         data={'description': 'test_publication321'})
        self.assertIsNotNone(self.project.publication_set.filter(description='test_publication321').first())


class SearchAndAPITest(TestCase):
    def setUp(self):
        self.auth_user, is_new = User.objects.get_or_create(username='testuser')
        self.user, is_new = HeliportUser.objects.get_or_create(auth_user=self.auth_user)
        self.project, is_new = Project.objects.get_or_create(owner=self.user)
        self.client.force_login(self.auth_user)

    def test_access_search(self):
        response = self.client.get(reverse('publication:search'))
        self.assertEquals(200, response.status_code)

    def test_publication_findable(self):
        Publication.objects.create(project=self.project, description='PUBLICATION321')
        response = self.client.get(f'{reverse("publication:search")}?q=321')
        self.assertContains(response, 'PUBLICATION321')

    def test_api(self):
        Publication.objects.create(project=self.project, description='PUBLICATION654')
        response = self.client.get(reverse('publication:api_root'))
        self.assertEquals(200, response.status_code)
        urls = json.loads(response.content.decode())
        response = self.client.get(urls['publications'])
        self.assertEquals(200, response.status_code)
        self.assertContains(response, 'PUBLICATION654')
