from django.urls import reverse

from heliport.graph_generator import Module


class VersionControlModule(Module):
    name = 'Version Control'
    module_id = 'version_control'

    def get_url(self, project):
        return reverse('version_control:list', kwargs={'project': project.pk})

    def is_configured(self, project):
        return project.versioncontrol_set.all()


def get_api_root():
    return reverse('version_control:api_root')


def get_search_url():
    return reverse('version_control:search')


def serialize_project(project):
    query = project.versioncontrol_set.all()
    result = dict()
    if query:
        result['heliport:has_VersionControl'] = [
            {
                'heliport:version_control_id': vc.version_control_id,
                'datacite:uri': vc.link,
                'rdfs:label': vc.name,
            }
            for vc in query
        ]

    return result
